@@ -1,17 +1,21 @@
+import asyncio
+import httpx
 import m3u8
+import os
 import re
-import requests
 import shutil
 import subprocess
 import tempfile
 
 from os import path
 from pathlib import Path
+from typing import OrderedDict
 from urllib.parse import urlparse, urlencode
 
 from twitchdl import twitch, utils
-from twitchdl.download import download_file, download_files
+from twitchdl.download import download_file
 from twitchdl.exceptions import ConsoleError
+from twitchdl.http import download_all
 from twitchdl.output import print_out
 
 
@@ -162,15 +166,20 @@ def _crete_temp_dir(base_uri):
 
 
 def download(args):
-    video_id = utils.parse_video_identifier(args.video)
+    for video in args.videos:
+        download_one(video, args)
+
+
+def download_one(video, args):
+    video_id = utils.parse_video_identifier(video)
     if video_id:
         return _download_video(video_id, args)
 
-    clip_slug = utils.parse_clip_identifier(args.video)
+    clip_slug = utils.parse_clip_identifier(video)
     if clip_slug:
         return _download_clip(clip_slug, args)
 
-    raise ConsoleError("Invalid input: {}".format(args.video))
+    raise ConsoleError("Invalid input: {}".format(video))
 
 
 def _get_clip_url(clip, quality):
@@ -274,7 +283,7 @@ def _download_video(video_id, args):
         args.overwrite = True
 
     print_out("<dim>Fetching access token...</dim>")
-    access_token = twitch.get_access_token(video_id)
+    access_token = twitch.get_access_token(video_id, auth_token=args.auth_token)
 
     print_out("<dim>Fetching playlists...</dim>")
     playlists_m3u8 = twitch.get_playlists(video_id, access_token)
@@ -283,7 +292,7 @@ def _download_video(video_id, args):
             else _select_playlist_interactive(playlists))
 
     print_out("<dim>Fetching playlist...</dim>")
-    response = requests.get(playlist_uri)
+    response = httpx.get(playlist_uri)
     response.raise_for_status()
     playlist = m3u8.loads(response.text)
 
@@ -299,11 +308,15 @@ def _download_video(video_id, args):
 
     print_out("\nDownloading {} VODs using {} workers to {}".format(
         len(vod_paths), args.max_workers, target_dir))
-    path_map = download_files(base_uri, target_dir, vod_paths, args.max_workers)
+    sources = [base_uri + path for path in vod_paths]
+    targets = [os.path.join(target_dir, "{:05d}.ts".format(k)) for k, _ in enumerate(vod_paths)]
+    asyncio.run(download_all(sources, targets, args.max_workers, rate_limit=args.rate_limit))
 
     # Make a modified playlist which references downloaded VODs
     # Keep only the downloaded segments and skip the rest
     org_segments = playlist.segments.copy()
+
+    path_map = OrderedDict(zip(vod_paths, targets))
     playlist.segments.clear()
     for segment in org_segments:
         if segment.uri in path_map:
