@@ -2,6 +2,7 @@
 
 import logging
 import sys
+import re
 
 from argparse import ArgumentParser, ArgumentTypeError
 from collections import namedtuple
@@ -46,13 +47,31 @@ def pos_integer(value):
     return value
 
 
+def rate(value):
+    match = re.search(r"^([0-9]+)(k|m|)$", value, flags=re.IGNORECASE)
+
+    if not match:
+        raise ArgumentTypeError("must be an integer, followed by an optional 'k' or 'm'")
+
+    amount = int(match.group(1))
+    unit = match.group(2)
+
+    if unit == "k":
+        return amount * 1024
+
+    if unit == "m":
+        return amount * 1024 * 1024
+
+    return amount
+
+
 COMMANDS = [
     Command(
         name="videos",
-        description="List videos from a channel",
+        description="List videos for a channel.",
         arguments=[
             (["channel_name"], {
-                "help": "channel name",
+                "help": "Name of the channel to list videos for.",
                 "type": str,
             }),
             (["-g", "--game"], {
@@ -61,9 +80,8 @@ COMMANDS = [
                 "type": str,
             }),
             (["-l", "--limit"], {
-                "help": "Number of videos to fetch (default 10)",
+                "help": "Number of videos to fetch. Defaults to 40 in copmpact mode, 10 otherwise.",
                 "type": pos_integer,
-                "default": 10,
             }),
             (["-a", "--all"], {
                 "help": "Fetch all videos, overrides --limit",
@@ -71,36 +89,41 @@ COMMANDS = [
                 "default": False,
             }),
             (["-s", "--sort"], {
-                "help": "Sorting order of videos. (default: time)",
+                "help": "Sorting order of videos. Defaults to `time`.",
                 "type": str,
                 "choices": ["views", "time"],
                 "default": "time",
             }),
             (["-t", "--type"], {
-                "help": "Broadcast type. (default: archive)",
+                "help": "Broadcast type. Defaults to `archive`.",
                 "type": str,
                 "choices": ["archive", "highlight", "upload"],
                 "default": "archive",
             }),
             (["-j", "--json"], {
-                "help": "Show results as JSON. Ignores --pager.",
+                "help": "Show results as JSON. Ignores `--pager`.",
                 "action": "store_true",
                 "default": False,
             }),
             (["-p", "--pager"], {
-                "help": "Number of videos to show per page. Disabled by default.",
+                "help": "Print videos in pages. Ignores `--limit`. Defaults to 10.",
                 "type": pos_integer,
                 "nargs": "?",
                 "const": 10,
             }),
+            (["-c", "--compact"], {
+                "help": "Show videos in compact mode, one line per video",
+                "action": "store_true",
+                "default": False,
+            }),
         ],
     ),
     Command(
         name="clips",
-        description="List clips",
+        description="List or download clips for a channel.",
         arguments=[
             (["channel_name"], {
-                "help": "channel name",
+                "help": "Name of the channel to list clips for.",
                 "type": str,
             }),
             (["-l", "--limit"], {
@@ -114,13 +137,13 @@ COMMANDS = [
                 "default": False,
             }),
             (["-P", "--period"], {
-                "help": "Period from which to return clips. (default: 'all_time')",
+                "help": "Period from which to return clips. Defaults to `all_time`.",
                 "type": str,
                 "choices": ["last_day", "last_week", "last_month", "all_time"],
                 "default": "all_time",
             }),
             (["-j", "--json"], {
-                "help": "Show results as JSON",
+                "help": "Show results as JSON. Ignores `--pager`.",
                 "action": "store_true",
                 "default": False,
             }),
@@ -139,17 +162,17 @@ COMMANDS = [
     ),
     Command(
         name="download",
-        description="Download a video",
+        description="Download videos or clips.",
         arguments=[
-            (["video"], {
-                "help": "video ID, clip slug, or URL",
+            (["videos"], {
+                "help": "One or more video ID, clip slug or twitch URL to download.",
                 "type": str,
+                "nargs": "+",
             }),
             (["-w", "--max-workers"], {
-                "help": "maximal number of threads for downloading vods "
-                        "concurrently (default 20)",
+                "help": "Number of workers for downloading vods concurrently (default 5)",
                 "type": int,
-                "default": 20,
+                "default": 5,
             }),
             (["-s", "--start"], {
                 "help": "Download video from this time (hh:mm or hh:mm:ss)",
@@ -163,7 +186,7 @@ COMMANDS = [
             }),
             (["-f", "--format"], {
                 "help": "Video format to convert into, passed to ffmpeg as the "
-                        "target file extension (default: mkv)",
+                        "target file extension. Defaults to `mkv`.",
                 "type": str,
                 "default": "mkv",
             }),
@@ -176,6 +199,13 @@ COMMANDS = [
                 "help": "Video quality, e.g. 720p. Set to 'source' to get best quality.",
                 "type": str,
             }),
+            (["-a", "--auth-token"], {
+                "help": "Authentication token, passed to Twitch to access subscriber only "
+                        "VODs. Can be copied from the 'auth_token' cookie in any browser "
+                        "logged in on Twitch.",
+                "type": str,
+                "default": None,
+            }),
             (["--no-join"], {
                 "help": "Don't run ffmpeg to join the downloaded vods, implies --keep.",
                 "action": "store_true",
@@ -190,15 +220,20 @@ COMMANDS = [
                 "help": "Output file name template. See docs for details.",
                 "type": str,
                 "default": "{date}_{id}_{channel_login}_{title_slug}.{format}"
-            })
+            }),
+            (["-r", "--rate-limit"], {
+                "help": "Limit the maximum download speed in bytes per second. "
+                        "Use 'k' and 'm' suffixes for kbps and mbps.",
+                "type": rate,
+            }),
         ],
     ),
     Command(
         name="info",
-        description="Print information for a given Twitch URL, video ID or clip slug",
+        description="Print information for a given Twitch URL, video ID or clip slug.",
         arguments=[
-            (["identifier"], {
-                "help": "identifier",
+            (["video"], {
+                "help": "Video ID, clip slug, or URL",
                 "type": str,
             }),
             (["-j", "--json"], {
@@ -238,7 +273,11 @@ def get_parser():
     subparsers = parser.add_subparsers(title="commands")
 
     for command in COMMANDS:
-        sub = subparsers.add_parser(command.name, help=command.description)
+        sub = subparsers.add_parser(
+            command.name,
+            description=command.description,
+            epilog=CLIENT_WEBSITE
+        )
 
         # Set the function to call to the function of same name in the "commands" package
         sub.set_defaults(func=commands.__dict__.get(command.name))
@@ -270,7 +309,7 @@ def main():
         print_err(e)
         sys.exit(1)
     except KeyboardInterrupt:
-        print_err("Operation canceled")
+        print_err("\nOperation canceled")
         sys.exit(1)
     except GQLError as e:
         print_err(e)
