@@ -2,7 +2,7 @@
 Twitch API access.
 """
 
-import requests
+import httpx
 
 from twitchdl import CLIENT_ID
 from twitchdl.exceptions import ConsoleError
@@ -17,7 +17,7 @@ class GQLError(Exception):
 def authenticated_get(url, params={}, headers={}):
     headers['Client-ID'] = CLIENT_ID
 
-    response = requests.get(url, params, headers=headers)
+    response = httpx.get(url, params=params, headers=headers)
     if 400 <= response.status_code < 500:
         data = response.json()
         # TODO: this does not look nice in the console since data["message"]
@@ -32,7 +32,7 @@ def authenticated_get(url, params={}, headers={}):
 def authenticated_post(url, data=None, json=None, headers={}):
     headers['Client-ID'] = CLIENT_ID
 
-    response = requests.post(url, data=data, json=json, headers=headers)
+    response = httpx.post(url, data=data, json=json, headers=headers)
     if response.status_code == 400:
         data = response.json()
         raise ConsoleError(data["message"])
@@ -52,9 +52,9 @@ def gql_post(query):
     return response
 
 
-def gql_query(query):
+def gql_query(query, headers={}):
     url = "https://gql.twitch.tv/gql"
-    response = authenticated_post(url, json={"query": query}).json()
+    response = authenticated_post(url, json={"query": query}, headers=headers).json()
 
     if "errors" in response:
         raise GQLError(response["errors"])
@@ -303,7 +303,7 @@ def channel_videos_generator(channel_id, max_videos, sort, type, game_ids=None):
     return videos["totalCount"], _generator(videos, max_videos)
 
 
-def get_access_token(video_id):
+def get_access_token(video_id, auth_token=None):
     query = """
     {{
         videoPlaybackAccessToken(
@@ -322,8 +322,26 @@ def get_access_token(video_id):
 
     query = query.format(video_id=video_id)
 
-    response = gql_query(query)
-    return response["data"]["videoPlaybackAccessToken"]
+    headers = {}
+    if auth_token is not None:
+        headers['authorization'] = f'OAuth {auth_token}'
+
+    try:
+        response = gql_query(query, headers=headers)
+        return response["data"]["videoPlaybackAccessToken"]
+    except httpx.HTTPStatusError as error:
+        # Provide a more useful error message when server returns HTTP 401
+        # Unauthorized while using a user-provided auth token.
+        if error.response.status_code == 401:
+            if auth_token:
+                raise ConsoleError("Unauthorized. The provided auth token is not valid.")
+            else:
+                raise ConsoleError(
+                    "Unauthorized. This video may be subscriber-only. See docs:\n"
+                    "https://twitch-dl.bezdomni.net/commands/download.html#downloading-subscriber-only-vods"
+                )
+
+        raise
 
 
 def get_playlists(video_id, access_token):
@@ -332,7 +350,7 @@ def get_playlists(video_id, access_token):
     """
     url = "http://usher.twitch.tv/vod/{}".format(video_id)
 
-    response = requests.get(url, params={
+    response = httpx.get(url, params={
         "nauth": access_token['value'],
         "nauthsig": access_token['signature'],
         "allow_audio_only": "true",
